@@ -206,7 +206,136 @@ class JSON2EDCLineageFiles:
     def generate_attribute_lineage_entry(self, data):
         result = messages.message["ok"]
 
-        return result
+        entity_association_uuid = data["physical_entity_association"]
+        entity_assocation = self.get_entity_association(entity_association_uuid)
+        from_entities = self.get_source_entities(entity_assocation)
+        to_entities = self.get_target_entities(entity_assocation)
+
+        overall_result = messages.message["ok"]
+        nr_link = 0
+        for source_target_attribute_link  in data["source_target_attribute_links"]:
+            nr_link += 1
+            description="none"
+            formula="none"
+            to_attribute = source_target_attribute_link["transformation"]["to"]
+            # to_attribute has to be in one of the target entities
+            result_check, entity, to_attribute_name = self.get_entity_attribute(to_entities, to_attribute)
+            tgt_entity = self.get_entity(entity_uuid=entity)["name"]
+            if not result_check:
+                result = messages.message["target_attribute_not_in_target_entities"]
+                result["info"] = "to_attribute >%s< not found in target entities >%s<" % (to_attribute, str(to_entities))
+                overall_result = result
+                continue
+            if description in source_target_attribute_link:
+                description = source_target_attribute_link["description"]
+            if formula in source_target_attribute_link:
+                formula = source_target_attribute_link["formula"]
+            nr_from = 0
+            for from_attribute in source_target_attribute_link["transformation"]["from"]:
+                nr_from += 1
+                # print("from:", from_attribute, "to:", to_attribute)
+                # from_attribute has to be in one of the source entities
+                result_check, entity, from_attribute_name = self.get_entity_attribute(from_entities, from_attribute)
+                if not result_check:
+                    result = messages.message["source_attribute_not_in_source_entities"]
+                    result["info"] = "from_attribute >%s< (%s) not found in source entities >%s<" \
+                                     % (from_attribute, from_attribute_name, str(from_entities))
+                    overall_result = result
+                else:
+                    src_entity = self.get_entity(entity_uuid=entity)["name"]
+                    item = self.create_attribute_item(source_dataset=src_entity
+                                                      , source_attribute=from_attribute_name
+                                                      , target_dataset=tgt_entity
+                                                      , target_attribute=to_attribute_name)
+                    self.write_lineage_entry(item)
+
+        return overall_result
+
+    def create_attribute_item(self, source_dataset, source_attribute, target_dataset, target_attribute):
+        # get info from REF files, generated out of the Excel by excel2references
+        src_ref = self.get_dataset_ref("source", source_dataset)
+        if src_ref is None:
+            src_path = "NONE://" + source_dataset + "/" + source_attribute
+        else:
+            src_edc_datasource, src_prefix, src_layer, src_zone = self.get_datasource_ref(src_ref["src_zone"])
+            src_path = src_edc_datasource + "://" + src_prefix + src_ref["src_zone"] \
+                       + "/" + source_dataset + "/" + source_attribute
+        tgt_ref = self.get_dataset_ref("target", target_dataset)
+        if tgt_ref is None:
+            tgt_path = "NONE://" + target_dataset + "/" + target_attribute
+        else:
+            tgt_edc_datasource, tgt_prefix, tgt_layer, tgt_zone = self.get_datasource_ref(tgt_ref["tgt_zone"])
+            if tgt_zone is None or tgt_zone == "":
+                tgt_path = tgt_edc_datasource + "://" + tgt_prefix + tgt_layer \
+                           + "/" + target_dataset + "/" + target_attribute
+            else:
+                tgt_path = tgt_edc_datasource + "://" + tgt_prefix + tgt_ref["tgt_zone"] \
+                           + "/" + target_dataset + "/" + target_attribute
+
+        item = ["core.DirectionalDataFlow", "", "", src_path, tgt_path]
+        return item
+
+    def get_entity_attribute(self, entities, attribute):
+        """
+            Check if the attribute uuid is part of one of the entities in the provided list
+        :param entities:
+        :param attribute:
+        :return:
+        """
+        for entity in entities:
+            entity_attributes = self.get_attributes(entity)
+            for entity_attribute in entity_attributes:
+                if entity_attribute["uid"] == attribute:
+                    return True, entity, entity_attribute["name"]
+        return False, None, None
+
+    def get_attributes(self, entity):
+        for file in glob(self.json_directory + "*.json"):
+            with open(file) as f:
+                data = json.load(f)
+                if "meta" not in data:
+                    continue
+                meta = data["meta"]
+                if meta == "physical_attribute":
+                    if data["physical_entity"] == entity:
+                        return data["attribute_list"]
+        return None
+
+    def get_entity(self, entity_uuid):
+        for file in glob(self.json_directory + "*.json"):
+            with open(file) as f:
+                data = json.load(f)
+                if "meta" not in data:
+                    continue
+                meta = data["meta"]
+                if meta == "physical_entity":
+                    if data["uid"] == entity_uuid:
+                        return data
+        return None
+
+    def get_entity_association(self, entity_assoc_id):
+        for file in glob(self.json_directory + "*.json"):
+            with open(file) as f:
+                data = json.load(f)
+                if "meta" not in data:
+                    continue
+                meta = data["meta"]
+                if meta == "physical_entity_association":
+                    if data["uid"] == entity_assoc_id:
+                        return data
+        return None
+
+    def get_source_entities(self, entity_assoc_id):
+        sources = []
+        for source_target_entity_link in entity_assoc_id["source_target_entity_links"]:
+            sources.append(source_target_entity_link["from"])
+        return sources
+
+    def get_target_entities(self, entity_assoc_id):
+        targets = []
+        for source_target_entity_link in entity_assoc_id["source_target_entity_links"]:
+            targets.append(source_target_entity_link["to"])
+        return targets
 
     def write_lineage_entry(self, entry):
         filename = self.output_directory + "lineage-" + self.start_time_formatted + ".csv"
@@ -225,7 +354,7 @@ class JSON2EDCLineageFiles:
 
     def register_result(self, file, result):
         print("Result for file >%s< is >%s<" % (file, result["code"]))
-        filename = self.output_directory + "results" + self.start_time_formatted + "-" + __name__ + ".txt"
+        filename = self.output_directory + "results-" + self.start_time_formatted + "-" + __name__ + ".txt"
         if path.exists(filename):
             append_or_write = "a"
         else:
